@@ -109,7 +109,7 @@ gnome_print_filter_set_property (GObject *object, guint n, const GValue *v,
 {
 	GnomePrintFilter *f = (GnomePrintFilter *) object;
 	gboolean b;
-	GValueArray *va;
+	GValueArray *va = NULL;
 	guint i;
 
 	switch (n) {
@@ -721,7 +721,7 @@ flush_impl (GnomePrintFilter *f)
 static void
 reset_impl (GnomePrintFilter *f)
 {
-	guint i, n;
+	guint i;
 
 	gnome_print_filter_clear_data (f);
 
@@ -1146,7 +1146,7 @@ static gchar *
 gnome_print_filter_description_rec (GnomePrintFilter *f, const gchar *in, 
 		gboolean brackets)
 {
-	gchar *u, *t, *buf;
+	gchar *u, *t = NULL, *buf;
 	guint i, n, n_props, j;
 	GParamSpec **props;
 
