@@ -759,12 +759,13 @@ gnome_print_setlinewidth (GnomePrintContext *pc, double width)
 int
 gnome_print_context_close (GnomePrintContext *pc)
 {
-	gint ret;
+	gint ret = GNOME_PRINT_OK;
 
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 
-	ret = GNOME_PRINT_OK;
+	if (pc->priv->filter)
+		gnome_print_filter_flush (pc->priv->filter);
 
 	if (GNOME_PRINT_CONTEXT_GET_CLASS (pc)->close)
 		ret = GNOME_PRINT_CONTEXT_GET_CLASS (pc)->close (pc);
